"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactDnd = require("react-dnd");

var _react2 = require("@emotion/react");

var _usePrefersColorScheme = require("../../hooks/usePrefersColorScheme");

var _types = require("./types");

var _jsxRuntime = require("@emotion/react/jsx-runtime");

/** @jsxImportSource @emotion/react */

/**
 * Specifies the drag source contract.
 * Only `beginDrag` function is required.
 */
const cardSource = {
  canDrag(props) {
    return props.item.color === props.turn;
  },

  isDragging(props, monitor) {
    // If your component gets unmounted while dragged
    // (like a card in Kanban board dragged between lists)
    // you can implement something like this to keep its
    // appearance dragged:
    return monitor.getItem().id === props.item.id;
  },

  beginDrag(props) {
    // Return the data describing the dragged item
    const item = props.item;
    return item;
  },

  endDrag(props, monitor) {
    if (!monitor.didDrop()) {
      // You can check whether the drop was successful
      // or if the drag ended but nobody handled the drop
      return;
    } // When dropped on a compatible target, do something.
    // Read the original dragged item from getItem():


    monitor.getItem(); // eslint-disable-line
    // You may also read the drop result from the drop target
    // that handled the drop, if it returned an object from
    // its drop() method.

    monitor.getDropResult(); // eslint-disable-line
    // This is a good place to call some Flux action
    // CardActions.moveCardToList(item.id, dropResult.listId);
  }

};
/**
 * Specifies which props to inject into your component.
 */

const collect = function (connect, monitor) {
  return {
    // Call this function inside render()
    // to let React DnD handle the drag events:
    connectDragSource: connect.dragSource(),
    // You can ask the monitor about the current drag state:
    isDragging: monitor.isDragging()
  };
};

const Piece = ({
  connectDragSource,
  item
}) => {
  const preferColor = (0, _usePrefersColorScheme.usePrefersColorScheme)();
  let itemColor = item.color;

  if (preferColor === 'dark' && itemColor === _types.ChessColor.Black) {
    itemColor = 'white';
  }

  return connectDragSource((0, _jsxRuntime.jsx)("div", {
    css: (0, _react2.css)`
        width: 50px;
        height: 50px;
        position: absolute;
        left: 50%;
        top: 50%;
        marginTop: -25px;
        marginLeft: -25px;
        fontSize: 30px;
        textAlign: center;
        lineHeight: 50px;
        border: 1px solid ${preferColor === 'dark' ? 'white' : 'black'};
        borderRadius: 50%;
        background-color: ${preferColor === 'dark' ? 'black' : 'white'};
        userSelect: none;
        color: ${itemColor};
      `,
    children: item.name
  }));
};

var _default = (0, _reactDnd.DragSource)('Piece', cardSource, collect)(Piece);

exports.default = _default;